diff --git a/docs/_asset/editor.jsx b/docs/_asset/editor.jsx
index 0960cb0cf..7f646f0b6 100644
--- a/docs/_asset/editor.jsx
+++ b/docs/_asset/editor.jsx
@@ -12,14 +12,14 @@
* @typedef {import('mdast-util-mdx-jsx').MdxJsxAttributeValueExpression} MdxJsxAttributeValueExpression
* @typedef {import('mdast-util-mdx-jsx').MdxJsxExpressionAttribute} MdxJsxExpressionAttribute
* @typedef {import('mdx/types.js').MDXModule} MDXModule
- * @typedef {import('react-error-boundary').FallbackProps} FallbackProps
+ * @typedef {import('react-error-boundary').FallbackProps} FallbackProperties
* @typedef {import('unified').PluggableList} PluggableList
* @typedef {import('unist').Node} UnistNode
*/
/**
- * @typedef DisplayProps
- * Props.
+ * @typedef DisplayProperties
+ * Properties.
* @property {Error} error
* Error.
*
@@ -204,7 +204,7 @@ function Playground() {
if (show === 'result') {
/** @type {MDXModule} */
- const mod = await run(String(file), {
+ const result = await run(String(file), {
...runtime,
baseUrl: window.location.href
})
@@ -214,7 +214,7 @@ function Playground() {
FallbackComponent={ErrorFallback}
resetKeys={[value]}
>
-
{mod.default({})}
+ {result.default({})}
)
}
@@ -567,19 +567,19 @@ function Playground() {
/**
*
- * @param {Readonly} props
- * Props.
+ * @param {Readonly} properties
+ * Properties.
* @returns {JSX.Element}
* Element.
*/
-function ErrorFallback(props) {
+function ErrorFallback(properties) {
// type-coverage:ignore-next-line
- const error = /** @type {Error} */ (props.error)
+ const error = /** @type {Error} */ (properties.error)
return (
Something went wrong:
-
@@ -587,19 +587,19 @@ function ErrorFallback(props) {
}
/**
- * @param {DisplayProps} props
- * Props.
+ * @param {DisplayProperties} properties
+ * Properties.
* @returns {JSX.Element}
* Element.
*/
-function DisplayError(props) {
+function DisplayError(properties) {
return (
{String(
- props.error.stack
- ? props.error.message + '\n' + props.error.stack
- : props.error
+ properties.error.stack
+ ? properties.error.message + '\n' + properties.error.stack
+ : properties.error
)}
@@ -638,8 +638,8 @@ function cleanUnistNode(node) {
node.attributes &&
Array.isArray(node.attributes)
) {
- for (const attr of node.attributes) {
- cleanUnistNode(attr)
+ for (const attribute of node.attributes) {
+ cleanUnistNode(attribute)
}
}
diff --git a/docs/_component/home.jsx b/docs/_component/home.jsx
index b4659ded1..949cead3d 100644
--- a/docs/_component/home.jsx
+++ b/docs/_component/home.jsx
@@ -7,13 +7,13 @@
/**
* @typedef {Exclude} Meta
*
- * @typedef Props
- * Props.
+ * @typedef Properties
+ * Properties.
* @property {string} name
* Name.
* @property {ReactNode} children
* Children.
- * @property {Item} navTree
+ * @property {Item} navigationTree
* Navigation tree.
* @property {Meta} meta
* Meta.
@@ -21,20 +21,20 @@
import React from 'react'
import {FootSite} from './foot-site.jsx'
-import {NavSite, NavSiteSkip} from './nav-site.jsx'
+import {NavigationSite, NavigationSiteSkip} from './nav-site.jsx'
/**
- * @param {Readonly} props
- * Props.
+ * @param {Readonly} properties
+ * Properties.
* @returns {JSX.Element}
* Element.
*/
-export function Home(props) {
- const {children, meta, name, navTree} = props
+export function Home(properties) {
+ const {children, meta, name, navigationTree} = properties
return (
-
+
{meta.schemaOrg ? (
diff --git a/docs/_component/blog.jsx b/docs/_component/blog.jsx
index 90be43caa..ff2b728fe 100644
--- a/docs/_component/blog.jsx
+++ b/docs/_component/blog.jsx
@@ -3,13 +3,13 @@
*/
/**
* @typedef EntryProps
* Props for `BlogEntry`.
* @property {Readonly- } item
* Item.
*
* @typedef GroupProps
* Props for `BlogGroup`.
* @property {string | undefined} [className]
* Class name.
* @property {ReadonlyArray
- } items
@@ -30,13 +30,13 @@ const runtime = {Fragment, jsx, jsxs}
const dateTimeFormat = new Intl.DateTimeFormat('en', {dateStyle: 'long'})
/**
- * @param {Readonly} props
- * Props.
+ * @param {Readonly} properties
+ * Properties.
* @returns {JSX.Element}
* Element.
*/
-export function BlogEntry(props) {
- const {item} = props
+export function BlogEntry(properties) {
+ const {item} = properties
const {data, name} = item
const {matter = {}, meta = {}} = data
const title = matter.title || meta.title
@@ -106,13 +106,18 @@ export function BlogEntry(props) {
}
/**
- * @param {Readonly} props
- * Props.
+ * @param {Readonly} properties
+ * Properties.
* @returns {JSX.Element}
* Element.
*/
-export function BlogGroup(props) {
- const {className, items, sort = 'navSortSelf,meta.title', ...rest} = props
+export function BlogGroup(properties) {
+ const {
+ className,
+ items,
+ sort = 'navSortSelf,meta.title',
+ ...rest
+ } = properties
const sorted = sortItems(items, sort)
return (
@@ -3,13 +3,13 @@
*/
/**
- * @typedef EntryProps
- * Props for `BlogEntry`.
+ * @typedef EntryProperties
+ * Properties for `BlogEntry`.
* @property {Readonly- } item
* Item.
@@ -3,13 +3,13 @@
* Item.
*
- * @typedef GroupProps
- * Props for `BlogGroup`.
+ * @typedef GroupProperties
+ * Properties for `BlogGroup`.
* @property {string | undefined} [className]
* Class name.